@@ -30,6 +30,7 @@ class CTabFilter extends CBaseComponent {
 		// Array of CTabFilterItem objects.
 		this._items = [];
 		this._active_item = null;
+		this.selected_filter_item = null;
 		this._filters_footer = null;
 		// NodeList of available templates (<script> DOM elements).
 		this._templates = {};
@@ -81,6 +82,11 @@ class CTabFilter extends CBaseComponent {
 			index++;
 		}
 
+		if (options.expanded_timeselector) {
+			this.setSelectedItem(this._timeselector);
+			this._timeselector.setExpanded();
+		}
+
 		this.#updateSeparators();
 	}
 
@@ -302,11 +308,15 @@ class CTabFilter extends CBaseComponent {
 	 * @param {CTabFilterItem} item  Item object to be set as selected item.
 	 */
 	setSelectedItem(item) {
+		if (this._active_item !== this._timeselector) {
+			this.selected_filter_item = this._active_item;
+		}
+
 		this._active_item = item;
 		this._active_item.unsetExpandedSubfilters();
 		item.setSelected();
 
-		if (item !== this._timeselector) {
+		if (item !== this._timeselector && item !== this.selected_filter_item) {
 			item._target.setAttribute('tabindex', 0);
 			item.setBrowserLocationToApplyUrl();
 		}
@@ -425,15 +435,25 @@ class CTabFilter extends CBaseComponent {
 
 				item.setFocused();
 
-				if (item !== this._timeselector) {
-					if (item.isSelected()) {
+				if (item === this._timeselector) {
+					this.profileUpdate('expanded_timeselector', {
+						value_int: item._expanded ? 0 : 1
+					}).then(() => {
+						this._options.expanded_timeselector = +item._expanded;
+						this._options.expanded = false;
+					});
+				}
+				else {
+					if (item.isSelected() || this._active_item === this._timeselector) {
 						this.profileUpdate('expanded', {
 							value_int: item._expanded ? 0 : 1
 						}).then(() => {
 							this._options.expanded = +item._expanded;
+							this._options.expanded_timeselector = false;
 						});
 					}
-					else {
+
+					if (!item.isSelected()) {
 						item.initUnsavedState();
 						this.profileUpdate('selected', {
 							value_int: item._index
